@@ -54,6 +54,7 @@ int cCriteria::LogoFadeInOut() {
     if (CompareChannelName(channelName, "FOX_Channel",    IGNORE_HD))                  return FADE_IN;
     if (CompareChannelName(channelName, "kabel_eins",     IGNORE_HD))                  return FADE_IN;
     if (CompareChannelName(channelName, "KiKA",           IGNORE_HD))                  return FADE_IN | FADE_OUT;
+    if (CompareChannelName(channelName, "NDR_FS",         IGNORE_HD | IGNORE_CITY))    return FADE_OUT;
     if (CompareChannelName(channelName, "N24_DOKU",       IGNORE_HD))                  return FADE_IN;
     if (CompareChannelName(channelName, "Nickelodeon",    IGNORE_HD))                  return FADE_IN | FADE_OUT;
     if (CompareChannelName(channelName, "NICK_MTV+",      IGNORE_HD))                  return FADE_IN | FADE_OUT;
@@ -171,7 +172,7 @@ bool cCriteria::IsInfoLogoChannel() {
     if (!channelName) return false;
     // for performance reason only known and tested channels
     if (CompareChannelName(channelName, "C8",              IGNORE_NOTHING))             return true;
-    if (CompareChannelName(channelName, "Comedy_Central",  IGNORE_HD))                  return true;
+//    if (CompareChannelName(channelName, "Comedy_Central",  IGNORE_HD))                  return true; // false info logo detection from short logo interuption
     if (CompareChannelName(channelName, "DMAX",            IGNORE_HD | IGNORE_COUNTRY)) return true;
     if (CompareChannelName(channelName, "kabel_eins",      IGNORE_HD))                  return true;   // only for info (e.g. Teletext)
     if (CompareChannelName(channelName, "Kabel_1_Austria", IGNORE_HD | IGNORE_COUNTRY)) return true;   // only for info (e.g. Teletext)
